==> ftpq-1.06.tar.gz: ftpq-1.06/src/config.c <==
/* ftpq: config.c

Copyright (C) 2000-2003 Mark Tranchant

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/

#include "ftpq.h"


int read_config (char **argv, int argidx) {

	char *ftpqrc;
	char *section;
	FILE *rcptr;
	struct passwd *userdets;
	uid_t this_uid;
	char temp[BUFSIZE];
	int found = 0;
	int at_end = 0;

	this_uid = getuid ();
	userdets = getpwuid (this_uid);

	ftpqrc = memalloc (strlen (userdets->pw_dir) + 9);
	sprintf (ftpqrc, "%s/%s", userdets->pw_dir, ".ftpqrc");

	rcptr = fileopen (ftpqrc, FO_READ, FO_NONEED);

	if (rcptr == NULL) {
		printf ("ftpq: config file %s not found! (aborted)\n", ftpqrc);
		free (ftpqrc);
		free (rcptr);
		return NOFTPQRC;
	}

	free (ftpqrc);

	section = memalloc (strlen (argv[argidx]) + 3);
	sprintf (section, "[%s]", argv[argidx]);

	while (at_end == 0 && found == 0) {
		if (fgets (buffer, BUFSIZE, rcptr) == NULL)
			at_end = 1;
		if (strstr (buffer, section) != NULL)
			found = 1;
	}

	if (found == 0) {
		fclose (rcptr);
		printf ("ftpq: can't find section %s in .ftpqrc! (aborted)\n", section);
		free (section);
		return NOSECTION;
	}

	free (section);

	at_end = 0;

	while (fgets (buffer, BUFSIZE, rcptr) != NULL && at_end == 0) {
		if (gv_host == NULL && sscanf (buffer, "-h %s", temp)) {
			gv_host = memalloc (strlen (temp) + 1);
			strcpy (gv_host, temp);
		}
		else if (gv_port == 21 && sscanf (buffer, "-P %d", &gv_port));
		else if (gv_login == NULL && sscanf (buffer, "-u %s", temp)) {
			gv_login = memalloc (strlen (temp) + 1);
			strcpy (gv_login, temp);
		}
		else if (gv_passwd == NULL && sscanf (buffer, "-p %s", temp)) {
			gv_passwd = memalloc (strlen (temp) + 1);
			strcpy (gv_passwd, temp);
		}
		else if (gv_acct == NULL && sscanf (buffer, "-a %s", temp)) {
			gv_acct = memalloc (strlen (temp) + 1);
			strcpy (gv_acct, temp);
		}
		else if (gv_rdir == NULL && sscanf (buffer, "-d %s", temp)) {
			gv_rdir = memalloc (strlen (temp) + 1);
			strcpy (gv_rdir, temp);
		}
		else
			at_end = 1;
	}

	fclose (rcptr);
	return OK;

}

==> ftpq-1.11.tar.gz: ftpq-1.11/src/config.c <==
/* ftpq: config.c

Copyright (C) 2000, 2001 Mark Tranchant

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/

#include "ftpq.h"


int read_config (char **argv, int argidx) {

	char *ftpqrc;
	char *section;
	FILE *rcptr;
	struct passwd *userdets;
	uid_t this_uid;
	char temp[BUFSIZE];
	int found = 0;
	int at_end = 0;

	this_uid = getuid ();
	userdets = getpwuid (this_uid);

	ftpqrc = memalloc (strlen (userdets->pw_dir) + 9);
	sprintf (ftpqrc, "%s/%s", userdets->pw_dir, ".ftpqrc");

	rcptr = fileopen (ftpqrc, FO_READ | FO_NONEED);

	if (rcptr == NULL) {
		printf ("ftpq: config file %s not found! (aborted)\n", ftpqrc);
		free (ftpqrc);
		free (rcptr);
		return NOFTPQRC;
	}

	free (ftpqrc);

	section = memalloc (strlen (argv[argidx]) + 3);
	sprintf (section, "[%s]", argv[argidx]);

	while (at_end == 0 && found == 0) {
		if (fgets (buffer, BUFSIZE, rcptr) == NULL)
			at_end = 1;
		if ((char *) strstr (buffer, section) != NULL)
			found = 1;
	}

	if (found == 0) {
		fclose (rcptr);
		printf ("ftpq: can't find section %s in .ftpqrc! (aborted)\n", section);
		free (section);
		return NOSECTION;
	}

	free (section);

	at_end = 0;

	while (fgets (buffer, BUFSIZE, rcptr) != NULL && at_end == 0) {
		if (gv.host == NULL && sscanf (buffer, "-h %s", temp)) {
			gv.host = memalloc (strlen (temp) + 1);
			strcpy (gv.host, temp);
		}
		else if (gv.port == 21 && sscanf (buffer, "-P %d", &gv.port));
		else if (gv.login == NULL && sscanf (buffer, "-u %s", temp)) {
			gv.login = memalloc (strlen (temp) + 1);
			strcpy (gv.login, temp);
		}
		else if (gv.passwd == NULL && sscanf (buffer, "-p %s", temp)) {
			gv.passwd = memalloc (strlen (temp) + 1);
			strcpy (gv.passwd, temp);
		}
		else if (gv.acct == NULL && sscanf (buffer, "-a %s", temp)) {
			gv.acct = memalloc (strlen (temp) + 1);
			strcpy (gv.acct, temp);
		}
		else
			at_end = 1;
	}

	fclose (rcptr);
	return OK;

}
